@@ -1,5 +1,5 @@
 /*
- * $Id: abook.c,v 1.40 2003/12/05 16:09:42 jheinonen Exp $
+ * $Id: abook.c,v 1.42 2004/06/30 19:47:42 jheinonen Exp $
  *
  * by JH <jheinonen@users.sourceforge.net>
  *
@@ -748,13 +748,13 @@ add_email_add_item(int quiet, char *name, char *email)
 				"you may want to use --add-email-quiet\n");
 			exit(1);
 		}
-		printf("Add ``%s <%s>'' to %s ? (y/n)\n",
-				name,
-				email,
-				datafile
-		);
+
 		do {
-			c = fgetc(in);
+			printf("Add ``%s <%s>'' to %s ? (y/n)\n",
+					name,
+					email,
+					datafile);
+			c = getc(in);
 			if(c == 'n' || c == 'N') {
 				fclose(in);
 				return 0;
