@@ -1,6 +1,6 @@
 
 /*
- * $Id: ui.c,v 1.29 2003/11/06 17:32:00 jheinonen Exp $
+ * $Id: ui.c,v 1.31 2004/04/19 17:08:00 jheinonen Exp $
  *
  * by JH <jheinonen@users.sourceforge.net>
  *
@@ -489,27 +489,30 @@ ui_clear_database()
 void
 ui_find(int next)
 {
-	int item;
+	int item = -1;
 	static char findstr[MAX_FIELD_LEN];
 	int search_fields[] = {NAME, EMAIL, NICK, -1};
 
+	clear_statusline();
+
 	if(next) {
 		if( !*findstr )
 			return;
 	} else {
 		char *s;
-		clear_statusline();
 		s = ui_readline("/", findstr, MAX_FIELD_LEN - 1, 0);
 		strncpy(findstr, s, MAX_FIELD_LEN);
 		refresh_screen();
 	}
 
-	if( (item = find_item(findstr, curitem + !!next,
-					search_fields )) >= 0 ) {
+	if( (item = find_item(findstr, curitem + !!next, search_fields)) < 0 &&
+			(item = find_item(findstr, 0, search_fields)) >= 0)
+		statusline_addstr("Search hit bottom, continuing at top");
+
+	if(item >= 0) {
 		curitem = item;
 		refresh_list();
 	}
-
 }
 
 
